rm(list=ls())
setwd("e:/ChoiceModels/")
library(maxLik)
library(randtoolbox)

dt <-read.csv("d1000.csv",header=T)

ns <- nrow(dt)  ## ns is number of samples
n.alt <- 5   ## number of alternatives
n.var <- 10   ## number of parameters
b0 <- rep(0,n.var)  ## set initial parameters
x <- array(0,c(ns,n.alt,n.var))  ## make independent variable matrix
y  <- array(0,c(ns,n.alt))  ## make choice result matrix
m.av <- array(1,c(ns,n.alt)) ## mode availability

np <- 2     #number of error term as MXL
nr <- 100
## making Halton sequence
 hm <- array(0,c(np,ns,nr))
 h <- array(0,c(ns*np*nr,2))
 h[,1] <- halton(ns*np*nr,dim=1,init=T,normal=F,usetime=F)
 h[,2] <- runif(ns*np*nr)  # randoms for scramble
 hn <- h[order(h[,2]),1]   # scrambling by sorting uniformR
 hn <- qnorm(hn)           # qnorm: to normalD, qlnorm: to log-normalD
 for (i in 1:np){
   a <- hn[( (i-1)*ns*nr+1 ):( i*ns*nr ) ]
   hm[i,,] <- matrix(a,ns*nr,T)
 }
## making normal random
#for(i in 1:np) hm[i,,] <- matrix(rnorm(ns*nr,0,1),ns*nr,T)

b0 <- c(-0.01726, -0.01694, 0.4128, 0.07561, -0.8467,
         0.6351, 0.5342, 2.652, -3.677, 0.4521, 0.5, 0.5)


## calculating choice probability
fr <-function(b) {
  u  <- matrix(0, nr=ns, nc=n.alt) ## utility function
  p  <- matrix(0, nr=ns, nc=n.alt) ## probability
  pp <- matrix(0, nr=ns, nc=n.alt) ## probability
  for(i in 1:n.alt) u[,i] <- x[,i,] %*% b[1:n.var]
  for(n in 1:nr){
    eu <- matrix(0, nr=ns, nc=n.alt)
    eu[,1] <- exp(u[,1]+b[n.var+1]*hm[1,,n])
    eu[,2] <- exp(u[,2]+b[n.var+2]*hm[2,,n])
    eu[,3] <- exp(u[,3]+b[n.var+1]*hm[1,,n])
    eu[,4] <- exp(u[,4]                    )
    eu[,5] <- exp(u[,5]+b[n.var+2]*hm[2,,n])
    for(i in 1:n.alt) p[,i] <- eu[,i]/rowSums(eu)
    pp <- pp + p
  }
  return(pp/nr)
}

## log likelihood function
sumfr <- function (x) {
  a <- sum( log( rowSums(fr(x)*y) ) ) ; print(a) #; print(Sys.time())
  return(a)
}
## set matrix of variables: x[, mode, parameter.num]
  x[,1,1] <- dt[, 2]; x[,2,1] <- dt[, 3]; x[,3,1] <- dt[, 4]; x[,4,1] <- dt[, 5]; x[,5,1] <- dt[, 6]
  x[,1,2] <- dt[, 7]; x[,2,2] <- dt[, 8]; x[,3,2] <- dt[, 9]; x[,4,2] <- dt[,10]; x[,5,2] <- dt[,11]
  x[,1,3] <- dt[,12]; x[,2,3] <- dt[,13]; x[,3,3] <- dt[,14]; x[,4,3] <- dt[,15]; x[,5,3] <- dt[,16]
  x[,1,4] <- dt[,17]; x[,2,4] <- dt[,18]; x[,3,4] <- dt[,19]; x[,4,4] <- dt[,20]; x[,5,4] <- dt[,21]
  x[,1,5] <- dt[,22]; x[,2,5] <- dt[,23]; x[,3,5] <- dt[,24]; x[,4,5] <- dt[,25]; x[,5,5] <- dt[,26]
  x[,1,6] <- dt[,27]; x[,2,6] <- dt[,28]; x[,3,6] <- dt[,29]; x[,4,6] <- dt[,30]; x[,5,6] <- dt[,31]
  x[,2,7] <- 1; x[,3,8] <- 1; x[,4,9] <- 1; x[,5,10] <- 1
  y <- array(0,c(ns,5))
  for(n in 1:ns) y[n,dt[n,1]] <- 1

system.time( res <- maxLik(sumfr,start=b0) )

print(res)
summary(res)

