rm(list=ls())
setwd("e:/ChoiceModels/")
library(maxLik)

dt <-read.csv("d1000.csv",header=T)

ns <- nrow(dt)  ## ns is number of samples
n.alt <- 5   ## number of alternatives
n.var <- 10   ## number of parameters
x <- array(0,c(ns,n.alt,n.var))  ## make independent variable matrix
y  <- array(0,c(ns,n.alt))  ## make choice result matrix
m.av <- array(1,c(ns,n.alt)) ## mode availability

## calculating choice probability
prob <- function(b) {
  u <- matrix(0, nr=ns, nc=n.alt) ## utility function
  p <- matrix(0, nr=ns, nc=n.alt) ## probability
  for(i in 1:n.alt) u[,i] <- exp( (x[,i,] %*% b[1:10])/b[n.var+1] )
  nes <- matrix(0, nr=ns, nc=n.nest)
  for(i in 1:n.nest){
    for(j in 1:a.nest[i]) nes[,i] <- nes[,i] + u[,aloc[i,j]] }
  deno <- numeric(ns)
  for(i in 1:n.nest) deno <- deno + (nes[,i])^b[n.var+1]
  for(i in 1:n.alt){
    p[,i] <- ( u[,i]*(nes[,alns[i]])^(b[n.var+1]-1) ) / deno }
  return(p)
}

## Log-Likelihood function of Logit Model
logit <- function(b) {
  p <- prob(b); prb <- rowSums(p*y)
  LL <- sum(log(prb)) #; print(LL)
  return(LL)
}

## set matrix of variables: x[, mode, parameter.num]
  x[,1,1] <- dt[, 2]; x[,2,1] <- dt[, 3]; x[,3,1] <- dt[, 4]; x[,4,1] <- dt[, 5]; x[,5,1] <- dt[, 6]
  x[,1,2] <- dt[, 7]; x[,2,2] <- dt[, 8]; x[,3,2] <- dt[, 9]; x[,4,2] <- dt[,10]; x[,5,2] <- dt[,11]
  x[,1,3] <- dt[,12]; x[,2,3] <- dt[,13]; x[,3,3] <- dt[,14]; x[,4,3] <- dt[,15]; x[,5,3] <- dt[,16]
  x[,1,4] <- dt[,17]; x[,2,4] <- dt[,18]; x[,3,4] <- dt[,19]; x[,4,4] <- dt[,20]; x[,5,4] <- dt[,21]
  x[,1,5] <- dt[,22]; x[,2,5] <- dt[,23]; x[,3,5] <- dt[,24]; x[,4,5] <- dt[,25]; x[,5,5] <- dt[,26]
  x[,1,6] <- dt[,27]; x[,2,6] <- dt[,28]; x[,3,6] <- dt[,29]; x[,4,6] <- dt[,30]; x[,5,6] <- dt[,31]
  x[,2,7] <- 1; x[,3,8] <- 1; x[,4,9] <- 1; x[,5,10] <- 1
  y <- array(0,c(ns,5))
  for(n in 1:ns) y[n,dt[n,1]] <- 1

para <- array(0,c(11,50))
tval <- array(0,c(11,50))
llk  <- array(0,c(4,50))
nl.st <- character(50)
b0 <- c(-0.01726, -0.01694, 0.4128, 0.07561, -0.8467,
         0.6351, 0.5342, 2.652, -3.677, 0.4521, 1)

nn <- 1; nest.name <- "n_1_2345";  nl.st[nn] <- nest.name
  n.nest <- 2 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 4
  aloc[1,1] <- 1
  aloc[2,1] <- 2; aloc[2,2] <- 3; aloc[2,3] <- 4; aloc[2,4] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <- 2; nest.name <- "n_2_1345";  nl.st[nn] <- nest.name
  n.nest <- 2 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 4
  aloc[1,1] <- 2
  aloc[2,1] <- 1; aloc[2,2] <- 3; aloc[2,3] <- 4; aloc[2,4] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <- 3; nest.name <- "n_3_1245";  nl.st[nn] <- nest.name
  n.nest <- 2 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 4
  aloc[1,1] <- 3
  aloc[2,1] <- 1; aloc[2,2] <- 2; aloc[2,3] <- 4; aloc[2,4] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <- 4; nest.name <- "n_4_1235";  nl.st[nn] <- nest.name
  n.nest <- 2 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 4
  aloc[1,1] <- 4
  aloc[2,1] <- 1; aloc[2,2] <- 2; aloc[2,3] <- 3; aloc[2,4] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <- 5; nest.name <- "n_5_1234";  nl.st[nn] <- nest.name
  n.nest <- 2 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 4
  aloc[1,1] <- 5
  aloc[2,1] <- 1; aloc[2,2] <- 2; aloc[2,3] <- 3; aloc[2,4] <- 4
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <- 6; nest.name <- "n_12_345"; nl.st[nn] <- nest.name
  n.nest <- 2 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 2; a.nest[2] <- 3
  aloc[1,1] <- 1; aloc[1,2] <- 2
  aloc[2,1] <- 3; aloc[2,2] <- 4; aloc[2,3] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <- 7; nest.name <- "n_13_245"; nl.st[nn] <- nest.name
  n.nest <- 2 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 2; a.nest[2] <- 3
  aloc[1,1] <- 1; aloc[1,2] <- 3
  aloc[2,1] <- 2; aloc[2,2] <- 4; aloc[2,3] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <- 8; nest.name <- "n_14_235"; nl.st[nn] <- nest.name
  n.nest <- 2 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 2; a.nest[2] <- 3
  aloc[1,1] <- 1; aloc[1,2] <- 4
  aloc[2,1] <- 2; aloc[2,2] <- 3; aloc[2,3] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <- 9; nest.name <- "n_15_234"; nl.st[nn] <- nest.name
  n.nest <- 2 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 2; a.nest[2] <- 3
  aloc[1,1] <- 1; aloc[1,2] <- 5
  aloc[2,1] <- 2; aloc[2,2] <- 3; aloc[2,3] <- 4
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-10; nest.name <- "n_23_145"; nl.st[nn] <- nest.name
  n.nest <- 2 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 2; a.nest[2] <- 3
  aloc[1,1] <- 2; aloc[1,2] <- 3
  aloc[2,1] <- 1; aloc[2,2] <- 4; aloc[2,3] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-11; nest.name <- "n_24_135"; nl.st[nn] <- nest.name
  n.nest <- 2 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 2; a.nest[2] <- 3
  aloc[1,1] <- 2; aloc[1,2] <- 4
  aloc[2,1] <- 1; aloc[2,2] <- 3; aloc[2,3] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-12; nest.name <- "n_25_134"; nl.st[nn] <- nest.name
  n.nest <- 2 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 2; a.nest[2] <- 3
  aloc[1,1] <- 2; aloc[1,2] <- 5
  aloc[2,1] <- 1; aloc[2,2] <- 3; aloc[2,3] <- 4
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-13; nest.name <- "n_34_125"; nl.st[nn] <- nest.name
  n.nest <- 2 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 2; a.nest[2] <- 3
  aloc[1,1] <- 3; aloc[1,2] <- 4
  aloc[2,1] <- 1; aloc[2,2] <- 2; aloc[2,3] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-14; nest.name <- "n_35_124"; nl.st[nn] <- nest.name
  n.nest <- 2 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 2; a.nest[2] <- 3
  aloc[1,1] <- 3; aloc[1,2] <- 5
  aloc[2,1] <- 1; aloc[2,2] <- 2; aloc[2,3] <- 4
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-15; nest.name <- "n_45_123"; nl.st[nn] <- nest.name
  n.nest <- 2 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 2; a.nest[2] <- 3
  aloc[1,1] <- 4; aloc[1,2] <- 5
  aloc[2,1] <- 1; aloc[2,2] <- 2; aloc[2,3] <- 3
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-16; nest.name <- "n_1_23_45"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 2; a.nest[3] <- 2
  aloc[1,1] <- 1
  aloc[2,1] <- 2; aloc[2,2] <- 3
  aloc[3,1] <- 4; aloc[3,2] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-17; nest.name <- "n_1_24_35"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 2; a.nest[3] <- 2
  aloc[1,1] <- 1
  aloc[2,1] <- 2; aloc[2,2] <- 4
  aloc[3,1] <- 3; aloc[3,2] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-18; nest.name <- "n_1_25_34"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 2; a.nest[3] <- 2
  aloc[1,1] <- 1
  aloc[2,1] <- 2; aloc[2,2] <- 5
  aloc[3,1] <- 3; aloc[3,2] <- 4
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-19; nest.name <- "n_2_13_45"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 2; a.nest[3] <- 2
  aloc[1,1] <- 2
  aloc[2,1] <- 1; aloc[2,2] <- 3
  aloc[3,1] <- 4; aloc[3,2] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-20; nest.name <- "n_2_14_35"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 2; a.nest[3] <- 2
  aloc[1,1] <- 2
  aloc[2,1] <- 1; aloc[2,2] <- 4
  aloc[3,1] <- 3; aloc[3,2] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-21; nest.name <- "n_2_15_34"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 2; a.nest[3] <- 2
  aloc[1,1] <- 2
  aloc[2,1] <- 1; aloc[2,2] <- 5
  aloc[3,1] <- 3; aloc[3,2] <- 4
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-22; nest.name <- "n_3_12_45"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 2; a.nest[3] <- 2
  aloc[1,1] <- 3
  aloc[2,1] <- 1; aloc[2,2] <- 2
  aloc[3,1] <- 4; aloc[3,2] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-23; nest.name <- "n_3_14_25"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 2; a.nest[3] <- 2
  aloc[1,1] <- 3
  aloc[2,1] <- 1; aloc[2,2] <- 4
  aloc[3,1] <- 2; aloc[3,2] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-24; nest.name <- "n_3_15_24"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 2; a.nest[3] <- 2
  aloc[1,1] <- 3
  aloc[2,1] <- 1; aloc[2,2] <- 5
  aloc[3,1] <- 2; aloc[3,2] <- 4
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-25; nest.name <- "n_4_12_35"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 2; a.nest[3] <- 2
  aloc[1,1] <- 4
  aloc[2,1] <- 1; aloc[2,2] <- 2
  aloc[3,1] <- 3; aloc[3,2] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-26; nest.name <- "n_4_13_25"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 2; a.nest[3] <- 2
  aloc[1,1] <- 4
  aloc[2,1] <- 1; aloc[2,2] <- 3
  aloc[3,1] <- 2; aloc[3,2] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-27; nest.name <- "n_4_15_23"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 2; a.nest[3] <- 2
  aloc[1,1] <- 4
  aloc[2,1] <- 1; aloc[2,2] <- 5
  aloc[3,1] <- 2; aloc[3,2] <- 3
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-28; nest.name <- "n_5_12_34"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 2; a.nest[3] <- 2
  aloc[1,1] <- 5
  aloc[2,1] <- 1; aloc[2,2] <- 2
  aloc[3,1] <- 3; aloc[3,2] <- 4
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-29; nest.name <- "n_5_13_24"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 2; a.nest[3] <- 2
  aloc[1,1] <- 5
  aloc[2,1] <- 1; aloc[2,2] <- 3
  aloc[3,1] <- 2; aloc[3,2] <- 4
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-30; nest.name <- "n_5_14_23"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 2; a.nest[3] <- 2
  aloc[1,1] <- 5
  aloc[2,1] <- 1; aloc[2,2] <- 4
  aloc[3,1] <- 2; aloc[3,2] <- 3
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-31; nest.name <- "n_1_2_3_45"; nl.st[nn] <- nest.name
  n.nest <- 4 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 1; a.nest[4] <- 2
  aloc[1,1] <- 1
  aloc[2,1] <- 2
  aloc[3,1] <- 3
  aloc[4,1] <- 4; aloc[4,2] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-32; nest.name <- "n_1_2_4_35"; nl.st[nn] <- nest.name
  n.nest <- 4 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 1; a.nest[4] <- 2
  aloc[1,1] <- 1
  aloc[2,1] <- 2
  aloc[3,1] <- 4
  aloc[4,1] <- 3; aloc[4,2] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-33; nest.name <- "n_1_3_4_25"; nl.st[nn] <- nest.name
  n.nest <- 4 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 1; a.nest[4] <- 2
  aloc[1,1] <- 1
  aloc[2,1] <- 3
  aloc[3,1] <- 4
  aloc[4,1] <- 2; aloc[4,2] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-34; nest.name <- "n_2_3_4_15"; nl.st[nn] <- nest.name
  n.nest <- 4 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 1; a.nest[4] <- 2
  aloc[1,1] <- 2
  aloc[2,1] <- 3
  aloc[3,1] <- 4
  aloc[4,1] <- 1; aloc[4,2] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-35; nest.name <- "n_1_2_5_34"; nl.st[nn] <- nest.name
  n.nest <- 4 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 1; a.nest[4] <- 2
  aloc[1,1] <- 1
  aloc[2,1] <- 2
  aloc[3,1] <- 5
  aloc[4,1] <- 3; aloc[4,2] <- 4
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-36; nest.name <- "n_1_3_5_24"; nl.st[nn] <- nest.name
  n.nest <- 4 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 1; a.nest[4] <- 2
  aloc[1,1] <- 1
  aloc[2,1] <- 3
  aloc[3,1] <- 5
  aloc[4,1] <- 2; aloc[4,2] <- 4
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-37; nest.name <- "n_2_3_5_14"; nl.st[nn] <- nest.name
  n.nest <- 4 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 1; a.nest[4] <- 2
  aloc[1,1] <- 2
  aloc[2,1] <- 3
  aloc[3,1] <- 5
  aloc[4,1] <- 1; aloc[4,2] <- 4
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-38; nest.name <- "n_1_4_5_23"; nl.st[nn] <- nest.name
  n.nest <- 4 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 1; a.nest[4] <- 2
  aloc[1,1] <- 1
  aloc[2,1] <- 4
  aloc[3,1] <- 5
  aloc[4,1] <- 2; aloc[4,2] <- 3
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-39; nest.name <- "n_2_4_5_13"; nl.st[nn] <- nest.name
  n.nest <- 4 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 1; a.nest[4] <- 2
  aloc[1,1] <- 2
  aloc[2,1] <- 4
  aloc[3,1] <- 5
  aloc[4,1] <- 1; aloc[4,2] <- 3
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-40; nest.name <- "n_3_4_5_12"; nl.st[nn] <- nest.name
  n.nest <- 4 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 1; a.nest[4] <- 2
  aloc[1,1] <- 3
  aloc[2,1] <- 4
  aloc[3,1] <- 5
  aloc[4,1] <- 1; aloc[4,2] <- 2
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-41; nest.name <- "n_1_2_345"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 3
  aloc[1,1] <- 1
  aloc[2,1] <- 2
  aloc[3,1] <- 3; aloc[3,2] <- 4; aloc[3,3] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-42; nest.name <- "n_1_3_245"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 3
  aloc[1,1] <- 1
  aloc[2,1] <- 3
  aloc[3,1] <- 2; aloc[3,2] <- 4; aloc[3,3] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-43; nest.name <- "n_1_4_235"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 3
  aloc[1,1] <- 1
  aloc[2,1] <- 4
  aloc[3,1] <- 2; aloc[3,2] <- 3; aloc[3,3] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-44; nest.name <- "n_1_5_234"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 3
  aloc[1,1] <- 1
  aloc[2,1] <- 5
  aloc[3,1] <- 2; aloc[3,2] <- 3; aloc[3,3] <- 4
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-45; nest.name <- "n_2_3_145"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 3
  aloc[1,1] <- 2
  aloc[2,1] <- 3
  aloc[3,1] <- 1; aloc[3,2] <- 4; aloc[3,3] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-46; nest.name <- "n_2_4_135"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 3
  aloc[1,1] <- 2
  aloc[2,1] <- 4
  aloc[3,1] <- 1; aloc[3,2] <- 3; aloc[3,3] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-47; nest.name <- "n_2_5_134"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 3
  aloc[1,1] <- 2
  aloc[2,1] <- 5
  aloc[3,1] <- 1; aloc[3,2] <- 3; aloc[3,3] <- 4
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-48; nest.name <- "n_3_4_125"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 3
  aloc[1,1] <- 3
  aloc[2,1] <- 4
  aloc[3,1] <- 1; aloc[3,2] <- 2; aloc[3,3] <- 5
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-49; nest.name <- "n_3_5_124"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 3
  aloc[1,1] <- 3
  aloc[2,1] <- 5
  aloc[3,1] <- 1; aloc[3,2] <- 2; aloc[3,3] <- 4
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

nn <-50; nest.name <- "n_4_5_123"; nl.st[nn] <- nest.name
  n.nest <- 3 ; a.nest <- numeric(n.nest); aloc <- array(0,c(4,4))
  a.nest[1] <- 1; a.nest[2] <- 1; a.nest[3] <- 3
  aloc[1,1] <- 4
  aloc[2,1] <- 5
  aloc[3,1] <- 1; aloc[3,2] <- 2; aloc[3,3] <- 3
  alns <- numeric(5); for(i in 1:n.nest) for(j in 1:a.nest[i]) alns[aloc[i,j]] <- i
  st <- system.time( res <- maxLik(logit, start=b0) )
  b <- res$estimate; hhh<-res$hessian
  t <- b/sqrt(-diag(solve(hhh)))
  L0 <- 0; for(i in 1:n.alt) L0 <- L0 + sum(y[,i])*log(sum(y[,i])/ns)
  LL <- res$maximum
  print(nest.name)
  cat(" L(0)=",L0,"\n"); cat(" L(*)=",LL,"\n")
  rho <- (L0-LL)/L0; rhob <- (L0-(LL-length(b)))/L0
  cat(" rho=",rho,"  rho-bar=",rhob,"\n")
  for(i in 1:(n.var+1)) cat(i,",",signif(b[i],digits=7),",",round(t[i],digits=2),"\n")
  para[,nn] <- b; tval[,nn] <- t
  llk[1,nn] <- LL; llk[2,nn] <- rho; llk[3,nn] <- rhob; llk[4,nn] <- st[3]

#############################

write.csv(para ,"NL50-para.csv",row.names=F)
write.csv(tval ,"NL50-tval.csv",row.names=F)
write.csv(llk  ,"NL50-llk.csv",row.names=F)
write.csv(nl.st,"NL50name.csv",row.names=F)

#############################


